@@ -1,5 +1,4 @@
 import pkg_resources
-import os.path
 import argparse
 import logging
 import sys
@@ -45,8 +44,8 @@ class CommandManager(object):
                 continue
             try:
                 cmd = ep.load()
-                assert hasattr(cmd, 'run')
-            except Exception, e:  # pragma: nocover
+                cmd.run  # ensure existance; catch AttributeError otherwise
+            except Exception as e:  # pragma: nocover
                 warn("Unable to load plugin %s: %s" % (ep, e), RuntimeWarning)
                 continue
             self.add({ep.name: cmd})
@@ -60,9 +59,11 @@ class CommandRunner(object):
 
     def __init__(self):
         self.manager = CommandManager()
-        self.parser = HelpfulArgumentParser(
-            version='Pecan %s' % self.version,
-            add_help=True
+        self.parser = HelpfulArgumentParser(add_help=True)
+        self.parser.add_argument(
+            '--version',
+            action='version',
+            version='Pecan %s' % self.version
         )
         self.parse_sub_commands()
 
@@ -78,13 +79,16 @@ class CommandRunner(object):
             )
             for arg in getattr(cmd, 'arguments', tuple()):
                 arg = arg.copy()
-                if isinstance(arg.get('name'), basestring):
+                if isinstance(arg.get('name'), str):
                     sub.add_argument(arg.pop('name'), **arg)
                 elif isinstance(arg.get('name'), list):
                     sub.add_argument(*arg.pop('name'), **arg)
 
     def run(self, args):
         ns = self.parser.parse_args(args)
+        if ns.command_name is None:
+            self.run(['--help'])
+            return
         self.commands[ns.command_name]().run(ns)
 
     @classmethod
@@ -101,7 +105,20 @@ class CommandRunner(object):
         return self.manager.commands
 
 
-class BaseCommand(object):
+class BaseCommandMeta(type):
+
+    @property
+    def summary(cls):
+        """
+        This is used to populate the --help argument on the command line.
+
+        This provides a default behavior which takes the first sentence of the
+        command's docstring and uses it.
+        """
+        return cls.__doc__.strip().splitlines()[0].rstrip('.')
+
+
+class BaseCommandParent(object):
     """
     A base interface for Pecan commands.
 
@@ -126,14 +143,10 @@ class BaseCommand(object):
 
             def run(self, args):
                 super(SomeCommand, self).run(args)
-                print args.extra_arg
+                if args.extra_arg:
+                    pass
     """
 
-    class __metaclass__(type):
-        @property
-        def summary(cls):
-            return cls.__doc__.strip().splitlines()[0].rstrip('.')
-
     arguments = ({
         'name': 'config_file',
         'help': 'a Pecan configuration file',
@@ -142,8 +155,13 @@ class BaseCommand(object):
     },)
 
     def run(self, args):
+        """To be implemented by subclasses."""
         self.args = args
 
     def load_app(self):
         from pecan import load_app
         return load_app(self.args.config_file)
+
+BaseCommand = BaseCommandMeta('BaseCommand', (BaseCommandParent,), {
+    '__doc__': BaseCommandParent.__doc__
+})
