@@ -7,16 +7,16 @@ from pecan.tests import PecanTestCase
 
 def simple_app(environ, start_response):
     start_response("200 OK", [('Content-type', 'text/plain')])
-    return ['requested page returned']
+    return [b'requested page returned']
 
 
 def error_docs_app(environ, start_response):
     if environ['PATH_INFO'] == '/not_found':
         start_response("404 Not found", [('Content-type', 'text/plain')])
-        return ['Not found']
+        return [b'Not found']
     elif environ['PATH_INFO'] == '/error':
         start_response("200 OK", [('Content-type', 'text/plain')])
-        return ['Page not found']
+        return [b'Page not found']
     elif environ['PATH_INFO'] == '/recurse':
         raise ForwardRequestException('/recurse')
     else:
@@ -49,7 +49,7 @@ def forward(app):
     assert 'Page not found' in res
     try:
         res = app.get('/recurse')
-    except AssertionError, e:
+    except AssertionError as e:
         if str(e).startswith('Forwarding loop detected'):
             pass
         else:
@@ -126,7 +126,7 @@ class TestRecursiveMiddleware(PecanTestCase):
         assert 'Page not found' in res
         try:
             res = app.get('/recurse')
-        except AssertionError, e:
+        except AssertionError as e:
             if str(e).startswith('Forwarding loop detected'):
                 pass
             else:
